<?php

# JavaScript Auto Generator v0.1
# Класс для генерирования JavaScript-функции проверки формы
# Автор: Flexx (Ivan Pirog, admin@flexx.org.ua)
# URL: http://flexx.org.ua
#
# Конструктор FormValid(string FormName, string FunctionName, const Language);
#   где: FormName - Имя проверяемой формы
#        FunctionName - Имя функции проверки формы
#        Language - Язык выдаваемых сообщений (LANG_RU,LANG_EN)
#                   По умолчанию - русский
#
#------------------------------------------------------------------
#
# Функция AddIf - добавить проверку поля в функцию проверки
#   AddIf (string Item, string ItemName, const Type [, mixed Add])
#      где: Item - название поля (например: $Item="Email" если <input name="Email"...)
#           ItemName - название поля для вывода сообщения об ошибке
#           Type - тип проверки (по умолчанию ITEM_IS_EMPTY)
#           Add - добавочная переменная.
#
#   Type: ITEM_IS_EMPTY - проверка пустое ли поле. Если пустое - сообщить
#         ITEM_IS_NUM - проверка на число, т.е. поле должно быть цифровым
#         ITEM_IS_EMAIL - проверка на корректность E-mail
#         ITEM_IS_EMAIL_CLEAR - проверка на E-mail + очистка поля при ошибке
#         ITEM_IS_SMALL - проверка на кол-во символов. Не меньше чем значение в переменной Add
#         ITEM_IS_SMALL_CLEAR - -//- + очистка поля при ошибке
#         ITEM_IS_BIG - проверка на кол-во символов. Не больше чем значение в переменной Add
#         ITEM_IS_BIG_CLEAR - + очистка поля при ошибке
#-----------------------------------------------------------------------
#
# Функция Add - добавить свой кусок кода JavaScript
#   Add (string Code)
#     где: Code - кусок кода
#-----------------------------------------------------------------------
#
# Функция Out - вывод сгенерированного скрипта
#
#-----------------------------------------------------------------------
#
# Пример использования:
#
#   include('form.inc');
#
#   $MyForm = new FormValid('form','Check',LANG_RU);
#   $MyForm->AddIf('Name','Имя',ITEM_IS_EMPTY);
#   $MyForm->AddIf('Passw','Пароль',ITEM_IS_EMPTY);
#   $MyForm->AddIf('Passw','Пароль',ITEM_IS_SMALL_CLEAR,6);
#   $MyForm->AddIf('Word','Слово',ITEM_IS_EMPTY);
#   $MyForm->AddIf('Word','Слово',ITEM_IS_BIG,5);
#   $MyForm->AddIf('Email','E-mail',ITEM_IS_EMPTY);
#   $MyForm->AddIf('Email','',ITEM_IS_EMAIL);
#   $MyForm->Out();
#
# Форма:
#   <form method="POST" onsubmit="return Check()" name="form">
#     <table border=0 cellspacing=5 cellpadding=0>
#       <tr><td align=right>Твоё имя:</td><td><input name="Name" type="text"></td></tr>
#       <tr><td align=right>Пароль больше 6-ти символов:</td><td><input name="Passw" type="password"></td></tr>
#       <tr><td align=right>Слово меньше 5-ти символов:</td><td><input name="Word" type="text"></td></tr>
#       <tr><td align=right>E-mail:</td><td><input name="Email" type="text"></td></tr>
#       <tr><td></td><td><input type="submit" value="Угу"></td></tr>
#     </table>
#   </form>
#
#
# JavaScript, который сгенерирует класс:
#   <script language="JavaScript">
#   function Check(){
#   if(!f.Name.value){
#   alert('Обязательное поле "Имя" не заполнено.');
#   f.Name.focus();
#   return false;}
#   if(!f.Passw.value){
#   alert('Обязательное поле "Пароль" не заполнено.');
#   f.Passw.focus();
#   return false;}
#   jsfield = new String(f.Passw.value);
#   if (jsfield.length<6){
#   alert ('Поле "Пароль" должно быть длиннее 6 символов.');
#   f.Passw.value='';
#   f.Passw.focus();
#   return false;}
#   if(!f.Word.value){
#   alert('Обязательное поле "Слово" не заполнено.');
#   f.Word.focus();
#   return false;}
#   jsfield = new String(f.Word.value);
#   if (jsfield.length>5){
#   alert ('Поле "Слово" должно быть меньше 5 символов.');
#   f.Word.focus();
#   return false;}
#   if(!f.Email.value){
#   alert('Обязательное поле "E-mail" не заполнено.');
#   f.Email.focus();
#   return false;}
#   if(f.Email.value.indexOf('@',0)==-1){
#   alert ('E-mail адрес введён не корректно.');
#   f.Email.focus();
#   return false;}
#   return true; }
#   </script>
#
#


define('ITEM_IS_EMPTY'       ,1);
define('ITEM_IS_NUM'         ,2);
define('ITEM_IS_EMAIL'       ,3);
define('ITEM_IS_EMAIL_CLEAR' ,4);
define('ITEM_IS_SMALL'       ,5);
define('ITEM_IS_SMALL_CLEAR' ,6);
define('ITEM_IS_BIG'         ,7);
define('ITEM_IS_BIG_CLEAR'   ,8);
define('LANG_RU'             ,9);
define('LANG_EN'            ,10);

class FormValid
{
  var $Form;
  var $Out;
  var $Lang;

  function FormValid($FormName,$FunctionName,$Language=LANG_RU)
  {
    $this->Form = $FormName;
    $this->Lang = $Language;
    $this->Out = "<script language=\"JavaScript\">\r\n".
                 "function $FunctionName(){\r\n";
  }//function FormValid

  function AddIf($Item,$ItemName='',$VerifyType=ITEM_IS_EMPTY,$Add='')
  {
    switch($VerifyType)
    {
      case ITEM_IS_EMPTY:
        $this->Out.="if(!$this->Form.$Item.value){\r\n";
        if ($this->Lang==LANG_RU) $this->Out.="alert('Обязательное поле \"$ItemName\" не заполнено.');\r\n";
        if ($this->Lang==LANG_EN) $this->Out.="alert('The required field \"$ItemName\" is not filled.');\r\n";
        $this->Out.="$this->Form.$Item.focus();\r\n".
                    "return false;}\r\n";
      break;

      case ITEM_IS_NUM:
        $this->Out.="if(isNaN($this->Form.$Item.value)){\r\n";
        if ($this->Lang==LANG_RU) $this->Out.="alert('Обязательное поле \"$ItemName\" должно быть цифровым.');\r\n";
        if ($this->Lang==LANG_EN) $this->Out.="alert('The required field \"$ItemName\" should be digital.');\r\n";
        $this->Out.="$this->Form.$Item.focus();\r\n".
                    "return false;}\r\n";
      break;

      case ITEM_IS_EMAIL:
        $this->Out.="if($this->Form.$Item.value.indexOf('@',0)==-1){\r\n";
        if ($this->Lang==LANG_RU) $this->Out.="alert ('E-mail адрес введён не корректно.');\r\n";
        if ($this->Lang==LANG_EN) $this->Out.="alert ('E-mail should contain a proper e-mail address.');\r\n";
        $this->Out.="$this->Form.$Item.focus();\r\n".
                    "return false;}\r\n";
      break;

      case ITEM_IS_EMAIL_CLEAR:
        $this->Out.="if($this->Form.$Item.value.indexOf('@',0)==-1){\r\n";
        if ($this->Lang==LANG_RU) $this->Out.="alert ('E-mail адрес введён не корректно.');\r\n";
        if ($this->Lang==LANG_EN) $this->Out.="alert ('E-mail should contain a proper e-mail address.');\r\n";
        $this->Out.="$this->Form.$Item.value='';\r\n".
                    "$this->Form.$Item.focus();\r\n".
                    "return false;}\r\n";
      break;

      case ITEM_IS_SMALL:
        $this->Out.="jsfield = new String($this->Form.$Item.value);\r\n".
                    "if (jsfield.length<$Add){\r\n";
        if ($this->Lang==LANG_RU) $this->Out.="alert ('Поле \"$ItemName\" должно быть длиннее $Add символов.');\r\n";
        if ($this->Lang==LANG_EN) $this->Out.="alert ('The field \"$ItemName\" should be longer than $Add symbols.');\r\n";
        $this->Out.="$this->Form.$Item.focus();\r\n".
                    "return false;}\r\n";
      break;

      case ITEM_IS_SMALL_CLEAR:
        $this->Out.="jsfield = new String($this->Form.$Item.value);\r\n".
                    "if (jsfield.length<$Add){\r\n";
        if ($this->Lang==LANG_RU) $this->Out.="alert ('Поле \"$ItemName\" должно быть длиннее $Add символов.');\r\n";
        if ($this->Lang==LANG_EN) $this->Out.="alert ('The field \"$ItemName\" should be longer than $Add symbols.');\r\n";
        $this->Out.="$this->Form.$Item.value='';\r\n".
                    "$this->Form.$Item.focus();\r\n".
                    "return false;}\r\n";
      break;

      case ITEM_IS_BIG:
        $this->Out.="jsfield = new String($this->Form.$Item.value);\r\n".
                    "if (jsfield.length>$Add){\r\n";
        if ($this->Lang==LANG_RU) $this->Out.="alert ('Поле \"$ItemName\" должно быть меньше $Add символов.');\r\n";
        if ($this->Lang==LANG_EN) $this->Out.="alert ('The field \"$ItemName\" should be less than $Add symbols.');\r\n";
        $this->Out.="$this->Form.$Item.focus();\r\n".
                    "return false;}\r\n";
      break;

      case ITEM_IS_BIG_CLEAR:
        $this->Out.="jsfield = new String($this->Form.$Item.value);\r\n".
                    "if (jsfield.length>$Add){\r\n";
        if ($this->Lang==LANG_RU) $this->Out.="alert ('Поле \"$ItemName\" должно быть меньше $Add символов.');\r\n";
        if ($this->Lang==LANG_EN) $this->Out.="alert ('The field \"$ItemName\" should be less than $Add symbols.');\r\n";
        $this->Out.="$this->Form.$Item.value='';\r\n".
                    "$this->Form.$Item.focus();\r\n".
                    "return false;}\r\n";
      break;
    }//switch

  }//function AddIf

  function Add($Code)
  {
    $this->Out.=$Code;
  }//function Code

  function Out()
  {
    print $this->Out;
    print "return true; }\r\n";
    print "</script>\r\n";
    unset($this->Out);
    unset($this->Form);
    unset($this->Lang);
  }//function Out

}//class


?>